package org.kropp.examples;

import java.util.List;

import net.sf.xanswer.indexing.IndexException;

import org.kropp.index.Index;
import org.kropp.index.Query;
import org.kropp.index.impl.SearchEngine;
import org.kropp.util.xml.XMLIndexFactory;
import org.kropp.util.xml.XPathQuery;

/**
 * Example of XPath query in xml using index
 * 
 * @author Victor Kropp
 */
public class SearchXPath {
	/**
	 * Searches given xml file for given XPath query. Supported XPath subset is
	 * described in {@link org.kropp.util.xml.XPathQuery}
	 * 
	 * @param args
	 *            Command-line arguments.
	 */
	public static void main(String[] args) throws IndexException {
		if (args.length != 2) {
			System.err.println("Usage: java "
					+ new CurrentClassGetter().getName()
					+ " <XML file> <XPath query>");
			System.exit(1);
		}

		Index index = XMLIndexFactory.getInstance().openIndex(args[0], "");

		try {
			/*
			 * Creating query.
			 */
			Query query = new XPathQuery(args[1]);

			/*
			 * Making search.
			 */
			List<String> result = SearchEngine.search(index, query);
			System.out.println(result);
		} catch (Exception e) {
			System.err.println("Invalid or not supported XPath query.");
		}
	}

	private static class CurrentClassGetter extends SecurityManager {
		public String getName() {
			return getClassContext()[1].getName();
		}
	}
}
