package org.kropp.util;

import java.util.ArrayList;

abstract class AbstractBTreeNode<K extends Comparable<K>, V> {
	public abstract void put(K key, V value);

	public abstract V getValue(K key);

	public AbstractBTreeNode(int order) {
		this(order, null);
	}

	public AbstractBTreeNode(int order, AbstractBTreeNode<K, V> parent) {
		myOrder = order;
		myParent = parent;
		myKeys = new ArrayList<K>(order);
	}
	
	abstract void addNode(K key, AbstractBTreeNode<K, V> node);
	
	abstract K getMaxKey();
	
	/**
	 * Binary search for given key.
	 * 
	 * @param key
	 * @return Index of the nearest to <tt>key</tt> element in array.
	 */
	protected int indexOf(K key) {
		int left = 0;
		int right = myKeys.size() - 1;
		if (right < 0) {
			return -1;
		}
		int medium;
		while (left < right - 1) {
			medium = (left + right) / 2;
			if (myKeys.get(medium).compareTo(key) < 0) {
				left = medium;
			} else {
				right = medium;
			}
		}
		if (myKeys.get(left).compareTo(key) >= 0) {
			return left;
		} else {
			return right;
		}
	}

	@Override
	public String toString() {
		return myKeys.toString();
	}

	protected int myOrder;

	protected ArrayList<K> myKeys;
	
	protected AbstractBTreeNode<K,V> myParent;
}