package org.kropp.util.xml;

import org.kropp.index.AbstractQuery;
import org.kropp.index.Condition;

/**
 * Implements simple XPath queries parsing. Currently supports:
 * <ul>
 * <li>All axes: child, descendant, descendant-of-self, parent, ancestor,
 * ancestor-or-self, following, following-sibling, preceding, preceding-sibling,
 * attribute.</li>
 * <li><code>*</code> wildcard as nodeName supported.</li>
 * </ul>
 * 
 * @author Victor Kropp
 */
public class XPathQuery extends AbstractQuery {
	public XPathQuery(String xpath) {
		// Expanding //
		xpath = xpath.replaceAll("//", "/child::");

		// Transforming attributes
		xpath = xpath.replaceAll("@(.*)(=\"(.*)\")?", "/attribute::$1");

		String[] conditions = xpath.split("/");
		for (String condition : conditions) {
			if (condition.equals("")) {
				continue;
			}

			String[] parts = condition.split("::");
			String[] namevalue = { "" };
			Axis axis = Axis.CHILD;
			if (parts.length > 1) {
				axis = Axis.valueOf(parts[0].toUpperCase().replace('-', '_'));
				namevalue = parts[1].split("=");
			} else {
				namevalue = parts[0].split("=");
			}
			if (namevalue.length == 1) {
				addCondition(new Condition(axis, namevalue[0], ""));
			} else {
				addCondition(new Condition(axis, namevalue[0], namevalue[1]));
			}
		}
	}
}
